# -*- coding: UTF-8 -*-
import aiounittest
from unittest.mock import Mock, patch

from pydigitalstrom.devices.scene import DSScene, DSColorScene
from tests.common import get_testclient


class TestScene(aiounittest.AsyncTestCase):
    def test_initial(self):
        device = DSScene(
            client=get_testclient(), zone_id=1, zone_name='zone',
            scene_id=2, scene_name='scene')
        self.assertEqual(device.zone_id, 1)
        self.assertEqual(device.zone_name, 'zone')
        self.assertEqual(device.scene_id, 2)
        self.assertEqual(device.scene_name, 'scene')

    async def test_turn_on(self):
        with patch('pydigitalstrom.devices.scene.DSScene.request',
                   Mock(return_value=aiounittest.futurized(dict()))) as \
                mock_request:
            device = DSScene(
                client=get_testclient(), zone_id=1, zone_name='zone',
                scene_id=2, scene_name='scene')
            await device.turn_on()
            mock_request.assert_called_with(
                url='/json/zone/callScene?id=1&sceneNumber=2&force=true',
                check_result=False)


class TestColorScene(aiounittest.AsyncTestCase):
    def test_initial(self):
        device = DSColorScene(
            client=get_testclient(), zone_id=1, zone_name='zone',
            scene_id=2, scene_name='scene', color=1)
        self.assertEqual(device.zone_id, 1)
        self.assertEqual(device.zone_name, 'zone')
        self.assertEqual(device.scene_id, 2)
        self.assertEqual(device.scene_name, 'scene')
        self.assertEqual(device.color, 1)

    async def test_turn_on(self):
        with patch('pydigitalstrom.devices.scene.DSColorScene.request',
                   Mock(return_value=aiounittest.futurized(dict()))) as \
                mock_request:
            device = DSColorScene(
                client=get_testclient(), zone_id=1, zone_name='zone',
                scene_id=2, scene_name='scene', color=1)
            await device.turn_on()
            mock_request.assert_called_with(
                url='/json/zone/callScene?id=1&sceneNumber=2&groupID=1&'
                    'force=true',
                check_result=False)
